======
Guides
======

Practical how-to guides showing *findiff* in action for various use cases.

.. toctree::
    :maxdepth: 1

    basic-derivatives
    vector-calculus
    non-uniform-grids
    polar-coordinates
    periodic-bc
    matrix-representation
    compact-fd
    solving-pdes
    error-estimation
